=== modified file 'HACKING'
--- HACKING	2006-04-27 05:25:18 +0000
+++ HACKING	2006-06-04 15:39:43 +0000
@@ -194,6 +194,21 @@
     may not catch every case but it's still useful sometimes.
 
 
+Factories
+---------
+
+In some places we have variables which point to callables that construct
+new instances.  That is to say, they can be used a lot like class objects,
+but they shouldn't be *named* like classes:
+
+> I think that things named FooBar should create instances of FooBar when
+> called. Its plain confusing for them to do otherwise. When we have
+> something that is going to be used as a class - that is, checked for via
+> isinstance or other such idioms, them I would call it foo_class, so that
+> it is clear that a callable is not sufficient. If it is only used as a
+> factory, then yes, foo_factory is what I would use.
+
+
 Writing output
 ==============
 

=== modified file 'NEWS'
--- NEWS	2006-05-30 15:33:52 +0000
+++ NEWS	2006-06-06 10:19:21 +0000
@@ -38,7 +38,10 @@
      ftp support has been improved, including support for supplying a
      non-standard port. (John Arbash Meinel).
 
-   * ``log --line`` shows the revision number.  (#5162, Alexander Belchenko)
+   * 'bzr log --line' shows the revision number, and uses only the
+     first line of the log message (#5162, Alexander Belchenko;
+     Matthieu Moy)
+  
 
   BUG FIXES:
 

=== modified file 'bzrlib/benchmarks/bench_checkout.py'
--- bzrlib/benchmarks/bench_checkout.py	2006-05-22 09:17:55 +0000
+++ bzrlib/benchmarks/bench_checkout.py	2006-06-03 22:09:49 +0000
@@ -23,7 +23,7 @@
 
     def test_build_kernel_like_tree(self):
         """Checkout of a clean kernel sized tree should be (<10secs)."""
-        self.make_kernel_tree()
+        self.make_kernel_like_tree()
         self.run_bzr('add')
         self.run_bzr('commit', '-m', 'first post')
         # on robertc's machine the first sample of this took 105079ms/205417ms

=== modified file 'bzrlib/diff.py'
--- bzrlib/diff.py	2006-06-03 17:29:56 +0000
+++ bzrlib/diff.py	2006-06-06 05:29:39 +0000
@@ -14,6 +14,8 @@
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 
+import time
+
 from bzrlib.delta import compare_trees
 from bzrlib.errors import BzrError
 import bzrlib.errors as errors
@@ -54,8 +56,8 @@
     if sequence_matcher is None:
         sequence_matcher = bzrlib.patiencediff.PatienceSequenceMatcher
     ud = unified_diff(oldlines, newlines,
-                      fromfile=old_filename.encode(path_encoding)+'\t', 
-                      tofile=new_filename.encode(path_encoding)+'\t',
+                      fromfile=old_filename.encode(path_encoding),
+                      tofile=new_filename.encode(path_encoding),
                       sequencematcher=sequence_matcher)
 
     ud = list(ud)
@@ -111,9 +113,9 @@
         if not diff_opts:
             diff_opts = []
         diffcmd = ['diff',
-                   '--label', old_filename+'\t',
+                   '--label', old_filename,
                    oldtmpf.name,
-                   '--label', new_filename+'\t',
+                   '--label', new_filename,
                    newtmpf.name]
 
         # diff only allows one style to be specified; they don't override.
@@ -267,10 +269,9 @@
                      specific_files, external_diff_options, 
                      old_label='a/', new_label='b/' ):
 
-    DEVNULL = '/dev/null'
-    # Windows users, don't panic about this filename -- it is a
-    # special signal to GNU patch that the file should be created or
-    # deleted respectively.
+    # GNU Patch uses the epoch date to detect files that are being added
+    # or removed in a diff.
+    EPOCH_DATE = '1970-01-01 00:00:00 +0000'
 
     # TODO: Generation of pseudo-diffs for added/deleted files could
     # be usefully made into a much faster special case.
@@ -292,13 +293,19 @@
     for path, file_id, kind in delta.removed:
         has_changes = 1
         print >>to_file, '=== removed %s %r' % (kind, path.encode('utf8'))
-        old_tree.inventory[file_id].diff(diff_file, old_label + path, old_tree,
-                                         DEVNULL, None, None, to_file)
+        old_name = '%s%s\t%s' % (old_label, path,
+                                 _patch_header_date(old_tree, file_id, path))
+        new_name = '%s%s\t%s' % (new_label, path, EPOCH_DATE)
+        old_tree.inventory[file_id].diff(diff_file, old_name, old_tree,
+                                         new_name, None, None, to_file)
     for path, file_id, kind in delta.added:
         has_changes = 1
         print >>to_file, '=== added %s %r' % (kind, path.encode('utf8'))
-        new_tree.inventory[file_id].diff(diff_file, new_label + path, new_tree,
-                                         DEVNULL, None, None, to_file, 
+        old_name = '%s%s\t%s' % (old_label, path, EPOCH_DATE)
+        new_name = '%s%s\t%s' % (new_label, path,
+                                 _patch_header_date(new_tree, file_id, path))
+        new_tree.inventory[file_id].diff(diff_file, new_name, new_tree,
+                                         old_name, None, None, to_file, 
                                          reverse=True)
     for (old_path, new_path, file_id, kind,
          text_modified, meta_modified) in delta.renamed:
@@ -307,21 +314,37 @@
         print >>to_file, '=== renamed %s %r => %r%s' % (
                     kind, old_path.encode('utf8'),
                     new_path.encode('utf8'), prop_str)
-        _maybe_diff_file_or_symlink(old_label, old_path, old_tree, file_id,
-                                    new_label, new_path, new_tree,
+        old_name = '%s%s\t%s' % (old_label, old_path,
+                                 _patch_header_date(old_tree, file_id,
+                                                    old_path))
+        new_name = '%s%s\t%s' % (new_label, new_path,
+                                 _patch_header_date(new_tree, file_id,
+                                                    new_path))
+        _maybe_diff_file_or_symlink(old_name, old_tree, file_id,
+                                    new_name, new_tree,
                                     text_modified, kind, to_file, diff_file)
     for path, file_id, kind, text_modified, meta_modified in delta.modified:
         has_changes = 1
         prop_str = get_prop_change(meta_modified)
         print >>to_file, '=== modified %s %r%s' % (kind, path.encode('utf8'), prop_str)
+        old_name = '%s%s\t%s' % (old_label, path,
+                                 _patch_header_date(old_tree, file_id, path))
+        new_name = '%s%s\t%s' % (new_label, path,
+                                 _patch_header_date(new_tree, file_id, path))
         if text_modified:
-            _maybe_diff_file_or_symlink(old_label, path, old_tree, file_id,
-                                        new_label, path, new_tree,
+            _maybe_diff_file_or_symlink(old_name, old_tree, file_id,
+                                        new_name, new_tree,
                                         True, kind, to_file, diff_file)
 
     return has_changes
 
 
+def _patch_header_date(tree, file_id, path):
+    """Returns a timestamp suitable for use in a patch header."""
+    tm = time.gmtime(tree.get_file_mtime(file_id, path))
+    return time.strftime('%Y-%m-%d %H:%M:%S +0000', tm)
+
+
 def _raise_if_doubly_unversioned(specific_files, old_tree, new_tree):
     """Complain if paths are not versioned in either tree."""
     if not specific_files:
@@ -359,12 +382,12 @@
         return  ""
 
 
-def _maybe_diff_file_or_symlink(old_label, old_path, old_tree, file_id,
-                                new_label, new_path, new_tree, text_modified,
+def _maybe_diff_file_or_symlink(old_path, old_tree, file_id,
+                                new_path, new_tree, text_modified,
                                 kind, to_file, diff_file):
     if text_modified:
         new_entry = new_tree.inventory[file_id]
         old_tree.inventory[file_id].diff(diff_file,
-                                         old_label + old_path, old_tree,
-                                         new_label + new_path, new_entry, 
+                                         old_path, old_tree,
+                                         new_path, new_entry, 
                                          new_tree, to_file)

=== modified file 'bzrlib/lockable_files.py'
--- bzrlib/lockable_files.py	2006-05-05 08:29:29 +0000
+++ bzrlib/lockable_files.py	2006-06-01 09:36:09 +0000
@@ -73,13 +73,12 @@
         :param lock_class: Class of lock strategy to use: typically
             either LockDir or TransportLock.
         """
-        object.__init__(self)
         self._transport = transport
         self.lock_name = lock_name
         self._transaction = None
-        self._find_modes()
         self._lock_mode = None
         self._lock_count = 0
+        self._find_modes()
         esc_name = self._escape(lock_name)
         self._lock = lock_class(transport, esc_name,
                                 file_modebits=self._file_mode,

=== modified file 'bzrlib/log.py'
--- bzrlib/log.py	2006-05-18 06:19:10 +0000
+++ bzrlib/log.py	2006-06-06 10:19:21 +0000
@@ -461,7 +461,7 @@
             out.append("%d:" % revno)
         out.append(self.truncate(self.short_committer(rev), 20))
         out.append(self.date_string(rev))
-        out.append(self.message(rev).replace('\n', ' '))
+        out.append(rev.get_summary())
         return self.truncate(" ".join(out).rstrip('\n'), max_chars)
 
 

=== modified file 'bzrlib/revision.py'
--- bzrlib/revision.py	2006-05-27 03:23:29 +0000
+++ bzrlib/revision.py	2006-06-06 10:19:21 +0000
@@ -101,6 +101,11 @@
         reversed_result.reverse()
         return reversed_result
 
+    def get_summary(self):
+        """Get the first line of the log message for this revision.
+        """
+        return self.message.split('\n', 1)[0]
+
 
 def is_ancestor(revision_id, candidate_id, branch):
     """Return true if candidate_id is an ancestor of revision_id.

=== modified file 'bzrlib/revisionspec.py'
--- bzrlib/revisionspec.py	2006-05-23 10:51:37 +0000
+++ bzrlib/revisionspec.py	2006-05-24 00:06:33 +0000
@@ -261,18 +261,6 @@
         return len(self.revs)
 
 
-class RevisionSpec_revs:
-    def __init__(self, revs, branch):
-        self.revs = revs
-        self.branch = branch
-    def __getitem__(self, index):
-        r = self.branch.repository.get_revision(self.revs[index])
-        # TODO: Handle timezone.
-        return datetime.datetime.fromtimestamp(r.timestamp)
-    def __len__(self):
-        return len(self.revs)
-
-
 class RevisionSpec_date(RevisionSpec):
     prefix = 'date:'
     _date_re = re.compile(

=== modified file 'bzrlib/tests/blackbox/test_diff.py'
--- bzrlib/tests/blackbox/test_diff.py	2006-05-04 06:07:43 +0000
+++ bzrlib/tests/blackbox/test_diff.py	2006-05-13 07:00:36 +0000
@@ -19,12 +19,19 @@
 """
 
 import os
+import re
 
 import bzrlib
 from bzrlib.branch import Branch
 from bzrlib.tests.blackbox import ExternalBase
 
 
+def subst_dates(string):
+    """Replace date strings with constant values."""
+    return re.sub(r'\d{4}-\d{2}-\d{2} \d{2}:\d{2}:\d{2} [-\+]\d{4}',
+                  'YYYY-MM-DD HH:MM:SS +ZZZZ', string)
+
+
 class TestDiff(ExternalBase):
 
     def make_example_branch(test):
@@ -56,10 +63,10 @@
         file('hello', 'wt').write('hello world!\n')
         out, err = self.runbzr('diff --prefix old/:new/', retcode=1)
         self.assertEquals(err, '')
-        self.assertEqualDiff(out, '''\
+        self.assertEqualDiff(subst_dates(out), '''\
 === modified file 'hello'
---- old/hello\t
-+++ new/hello\t
+--- old/hello\tYYYY-MM-DD HH:MM:SS +ZZZZ
++++ new/hello\tYYYY-MM-DD HH:MM:SS +ZZZZ
 @@ -1,1 +1,1 @@
 -foo
 +hello world!
@@ -72,10 +79,10 @@
         file('hello', 'wt').write('hello world!\n')
         out, err = self.runbzr('diff -p1', retcode=1)
         self.assertEquals(err, '')
-        self.assertEqualDiff(out, '''\
+        self.assertEqualDiff(subst_dates(out), '''\
 === modified file 'hello'
---- old/hello\t
-+++ new/hello\t
+--- old/hello\tYYYY-MM-DD HH:MM:SS +ZZZZ
++++ new/hello\tYYYY-MM-DD HH:MM:SS +ZZZZ
 @@ -1,1 +1,1 @@
 -foo
 +hello world!
@@ -88,10 +95,10 @@
         file('hello', 'wt').write('hello world!\n')
         out, err = self.runbzr('diff -p0', retcode=1)
         self.assertEquals(err, '')
-        self.assertEqualDiff(out, '''\
+        self.assertEqualDiff(subst_dates(out), '''\
 === modified file 'hello'
---- hello\t
-+++ hello\t
+--- hello\tYYYY-MM-DD HH:MM:SS +ZZZZ
++++ hello\tYYYY-MM-DD HH:MM:SS +ZZZZ
 @@ -1,1 +1,1 @@
 -foo
 +hello world!
@@ -127,25 +134,27 @@
     def test_diff_branches(self):
         self.example_branches()
         # should open branch1 and diff against branch2, 
-        output = self.run_bzr_captured(['diff', '-r', 'branch:branch2', 
-                                        'branch1'],
-                                       retcode=1)
-        self.assertEquals(("=== modified file 'file'\n"
-                           "--- file\t\n"
-                           "+++ file\t\n"
-                           "@@ -1,1 +1,1 @@\n"
-                           "-new content\n"
-                           "+contents of branch1/file\n"
-                           "\n", ''), output)
-        output = self.run_bzr_captured(['diff', 'branch2', 'branch1'],
-                                       retcode=1)
-        self.assertEqualDiff(("=== modified file 'file'\n"
-                              "--- file\t\n"
-                              "+++ file\t\n"
+        out, err = self.run_bzr_captured(['diff', '-r', 'branch:branch2', 
+                                          'branch1'],
+                                         retcode=1)
+        self.assertEquals('', err)
+        self.assertEquals("=== modified file 'file'\n"
+                          "--- file\tYYYY-MM-DD HH:MM:SS +ZZZZ\n"
+                          "+++ file\tYYYY-MM-DD HH:MM:SS +ZZZZ\n"
+                          "@@ -1,1 +1,1 @@\n"
+                          "-new content\n"
+                          "+contents of branch1/file\n"
+                          "\n", subst_dates(out))
+        out, ett = self.run_bzr_captured(['diff', 'branch2', 'branch1'],
+                                         retcode=1)
+        self.assertEquals('', err)
+        self.assertEqualDiff("=== modified file 'file'\n"
+                              "--- file\tYYYY-MM-DD HH:MM:SS +ZZZZ\n"
+                              "+++ file\tYYYY-MM-DD HH:MM:SS +ZZZZ\n"
                               "@@ -1,1 +1,1 @@\n"
                               "-new content\n"
                               "+contents of branch1/file\n"
-                              "\n", ''), output)
+                              "\n", subst_dates(out))
 
     def example_branch2(self):
         self.build_tree(['branch1/', 'branch1/file1'], line_endings='binary')

=== modified file 'bzrlib/tests/blackbox/test_too_much.py'
--- bzrlib/tests/blackbox/test_too_much.py	2006-05-30 01:15:18 +0000
+++ bzrlib/tests/blackbox/test_too_much.py	2006-06-06 10:19:21 +0000
@@ -823,7 +823,8 @@
         max_width = terminal_width() - 1
         for line in log_out.splitlines():
             self.assert_(len(line) <= max_width, len(line))
-        self.assert_("this is my new commit and" in log_out)
+        self.assert_("this is my new commit and" not in log_out)
+        self.assert_("this is my new commit" in log_out)
 
         progress("file with spaces in name")
         mkdir('sub directory')

=== modified file 'bzrlib/tests/test_diff.py'
--- bzrlib/tests/test_diff.py	2006-06-03 17:29:56 +0000
+++ bzrlib/tests/test_diff.py	2006-06-06 05:29:39 +0000
@@ -14,11 +14,13 @@
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 
+import os
 from cStringIO import StringIO
 
-from bzrlib.diff import internal_diff
+from bzrlib.diff import internal_diff, show_diff_trees
 from bzrlib.errors import BinaryFile
 import bzrlib.patiencediff
+from bzrlib.tests import TestCase, TestCaseWithTransport, TestCaseInTempDir
 from bzrlib.tests import TestCase, TestCaseInTempDir
 
 
@@ -83,8 +85,8 @@
                     u'new_\xe5', ['new_text\n'], output)
         lines = output.getvalue().splitlines(True)
         self.check_patch(lines)
-        self.assertEquals(['--- old_\xc2\xb5\t\n',
-                           '+++ new_\xc3\xa5\t\n',
+        self.assertEquals(['--- old_\xc2\xb5\n',
+                           '+++ new_\xc3\xa5\n',
                            '@@ -1,1 +1,1 @@\n',
                            '-old_text\n',
                            '+new_text\n',
@@ -99,8 +101,8 @@
                     path_encoding='utf8')
         lines = output.getvalue().splitlines(True)
         self.check_patch(lines)
-        self.assertEquals(['--- old_\xc2\xb5\t\n',
-                           '+++ new_\xc3\xa5\t\n',
+        self.assertEquals(['--- old_\xc2\xb5\n',
+                           '+++ new_\xc3\xa5\n',
                            '@@ -1,1 +1,1 @@\n',
                            '-old_text\n',
                            '+new_text\n',
@@ -115,8 +117,8 @@
                     path_encoding='iso-8859-1')
         lines = output.getvalue().splitlines(True)
         self.check_patch(lines)
-        self.assertEquals(['--- old_\xb5\t\n',
-                           '+++ new_\xe5\t\n',
+        self.assertEquals(['--- old_\xb5\n',
+                           '+++ new_\xe5\n',
                            '@@ -1,1 +1,1 @@\n',
                            '-old_text\n',
                            '+new_text\n',
@@ -133,6 +135,117 @@
             'internal_diff should return bytestrings')
 
 
+class TestDiffDates(TestCaseWithTransport):
+
+    def setUp(self):
+        super(TestDiffDates, self).setUp()
+        self.wt = self.make_branch_and_tree('.')
+        self.b = self.wt.branch
+        self.build_tree_contents([
+            ('file1', 'file1 contents at rev 1\n'),
+            ('file2', 'file2 contents at rev 1\n')
+            ])
+        self.wt.add(['file1', 'file2'])
+        self.wt.commit(
+            message='Revision 1',
+            timestamp=1143849600, # 2006-04-01 00:00:00 UTC
+            timezone=0,
+            rev_id='rev-1')
+        self.build_tree_contents([('file1', 'file1 contents at rev 2\n')])
+        self.wt.commit(
+            message='Revision 2',
+            timestamp=1143936000, # 2006-04-02 00:00:00 UTC
+            timezone=28800,
+            rev_id='rev-2')
+        self.build_tree_contents([('file2', 'file2 contents at rev 3\n')])
+        self.wt.commit(
+            message='Revision 3',
+            timestamp=1144022400, # 2006-04-03 00:00:00 UTC
+            timezone=-3600,
+            rev_id='rev-3')
+        self.wt.remove(['file2'])
+        self.wt.commit(
+            message='Revision 4',
+            timestamp=1144108800, # 2006-04-04 00:00:00 UTC
+            timezone=0,
+            rev_id='rev-4')
+        self.build_tree_contents([
+            ('file1', 'file1 contents in working tree\n')
+            ])
+        # set the date stamps for files in the working tree to known values
+        os.utime('file1', (1144195200, 1144195200)) # 2006-04-05 00:00:00 UTC
+
+    def get_diff(self, tree1, tree2):
+        output = StringIO()
+        show_diff_trees(tree1, tree2, output,
+                        old_label='old/', new_label='new/')
+        return output.getvalue()
+
+    def test_diff_rev_tree_working_tree(self):
+        output = self.get_diff(self.wt.basis_tree(), self.wt)
+        # note that the date for old/file1 is from rev 2 rather than from
+        # the basis revision (rev 4)
+        self.assertEqualDiff(output, '''\
+=== modified file 'file1'
+--- old/file1\t2006-04-02 00:00:00 +0000
++++ new/file1\t2006-04-05 00:00:00 +0000
+@@ -1,1 +1,1 @@
+-file1 contents at rev 2
++file1 contents in working tree
+
+''')
+
+    def test_diff_rev_tree_rev_tree(self):
+        tree1 = self.b.repository.revision_tree('rev-2')
+        tree2 = self.b.repository.revision_tree('rev-3')
+        output = self.get_diff(tree1, tree2)
+        self.assertEqualDiff(output, '''\
+=== modified file 'file2'
+--- old/file2\t2006-04-01 00:00:00 +0000
++++ new/file2\t2006-04-03 00:00:00 +0000
+@@ -1,1 +1,1 @@
+-file2 contents at rev 1
++file2 contents at rev 3
+
+''')
+        
+    def test_diff_add_files(self):
+        tree1 = self.b.repository.revision_tree(None)
+        tree2 = self.b.repository.revision_tree('rev-1')
+        output = self.get_diff(tree1, tree2)
+        # the files have the epoch time stamp for the tree in which
+        # they don't exist.
+        self.assertEqualDiff(output, '''\
+=== added file 'file1'
+--- old/file1\t1970-01-01 00:00:00 +0000
++++ new/file1\t2006-04-01 00:00:00 +0000
+@@ -0,0 +1,1 @@
++file1 contents at rev 1
+
+=== added file 'file2'
+--- old/file2\t1970-01-01 00:00:00 +0000
++++ new/file2\t2006-04-01 00:00:00 +0000
+@@ -0,0 +1,1 @@
++file2 contents at rev 1
+
+''')
+
+    def test_diff_remove_files(self):
+        tree1 = self.b.repository.revision_tree('rev-3')
+        tree2 = self.b.repository.revision_tree('rev-4')
+        output = self.get_diff(tree1, tree2)
+        # the file has the epoch time stamp for the tree in which
+        # it doesn't exist.
+        self.assertEqualDiff(output, '''\
+=== removed file 'file2'
+--- old/file2\t2006-04-03 00:00:00 +0000
++++ new/file2\t1970-01-01 00:00:00 +0000
+@@ -1,1 +0,0 @@
+-file2 contents at rev 3
+
+''')
+
+
 class TestPatienceDiffLib(TestCase):
 
     def test_unique_lcs(self):

=== modified file 'bzrlib/tests/test_inv.py'
--- bzrlib/tests/test_inv.py	2006-05-27 09:06:37 +0000
+++ bzrlib/tests/test_inv.py	2006-06-01 07:57:24 +0000
@@ -196,8 +196,8 @@
                           "old_label", self.tree_1,
                           "/dev/null", None, None,
                           output)
-        self.assertEqual(output.getvalue(), "--- old_label\t\n"
-                                            "+++ /dev/null\t\n"
+        self.assertEqual(output.getvalue(), "--- old_label\n"
+                                            "+++ /dev/null\n"
                                             "@@ -1,1 +0,0 @@\n"
                                             "-foo\n"
                                             "\n")
@@ -208,8 +208,8 @@
                           "new_label", self.tree_1,
                           "/dev/null", None, None,
                           output, reverse=True)
-        self.assertEqual(output.getvalue(), "--- /dev/null\t\n"
-                                            "+++ new_label\t\n"
+        self.assertEqual(output.getvalue(), "--- /dev/null\n"
+                                            "+++ new_label\n"
                                             "@@ -0,0 +1,1 @@\n"
                                             "+foo\n"
                                             "\n")
@@ -220,8 +220,8 @@
                           "/dev/null", self.tree_1, 
                           "new_label", self.file_2, self.tree_2,
                           output)
-        self.assertEqual(output.getvalue(), "--- /dev/null\t\n"
-                                            "+++ new_label\t\n"
+        self.assertEqual(output.getvalue(), "--- /dev/null\n"
+                                            "+++ new_label\n"
                                             "@@ -1,1 +1,1 @@\n"
                                             "-foo\n"
                                             "+bar\n"

=== modified file 'bzrlib/tests/test_revisionnamespaces.py'
--- bzrlib/tests/test_revisionnamespaces.py	2006-05-23 10:51:37 +0000
+++ bzrlib/tests/test_revisionnamespaces.py	2006-05-24 00:06:33 +0000
@@ -1,4 +1,4 @@
-# Copyright (C) 2004, 2005 by Canonical Ltd
+# Copyright (C) 2004, 2005, 2006 by Canonical Ltd
 
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -56,8 +56,6 @@
                           (1, 'a@r-0-1'))
         self.assertEquals(RevisionSpec('before:date:today').in_history(b),
                           (1, 'a@r-0-1'))
-        self.assertRaises(NoSuchRevision,
-                          RevisionSpec('date:tomorrow').in_history, b)
 
         self.assertEquals(RevisionSpec('last:1').in_history(b),
                           (3, 'a@r-0-3'))

=== modified file 'bzrlib/tests/test_selftest.py'
--- bzrlib/tests/test_selftest.py	2006-05-24 12:55:08 +0000
+++ bzrlib/tests/test_selftest.py	2006-06-06 10:12:26 +0000
@@ -458,13 +458,13 @@
         self.time(time.sleep, 0.001)
         result.extractBenchmarkTime(self)
         timed_string = result._testTimeString()
-        self.assertContainsRe(timed_string, "^    [0-9]ms/   [ 1-9][0-9]ms$")
+        self.assertContainsRe(timed_string, "^   [ 1-9][0-9]ms/   [ 1-9][0-9]ms$")
         # extracting the time from a non-bzrlib testcase sets to None
         result._recordTestStartTime()
         result.extractBenchmarkTime(
             unittest.FunctionTestCase(self.test_elapsed_time_with_benchmarking))
         timed_string = result._testTimeString()
-        self.assertContainsRe(timed_string, "^          [0-9]ms$")
+        self.assertContainsRe(timed_string, "^         [ 1-9][0-9]ms$")
         # cheat. Yes, wash thy mouth out with soap.
         self._benchtime = None
 
@@ -509,10 +509,10 @@
         self.assertContainsRe(result_stream.getvalue(), 
             r"LSProf output for <type 'unicode'>\(\('hello',\), {'errors': 'replace'}\)\n"
             r" *CallCount *Recursive *Total\(ms\) *Inline\(ms\) *module:lineno\(function\)\n"
-            r" +1 +0 +0\.\d+ +0\.\d+ +<method 'disable' of '_lsprof\.Profiler' objects>\n"
+            r"( +1 +0 +0\.\d+ +0\.\d+ +<method 'disable' of '_lsprof\.Profiler' objects>\n)?"
             r"LSProf output for <type 'unicode'>\(\('world',\), {'errors': 'replace'}\)\n"
             r" *CallCount *Recursive *Total\(ms\) *Inline\(ms\) *module:lineno\(function\)\n"
-            r" +1 +0 +0\.\d+ +0\.\d+ +<method 'disable' of '_lsprof\.Profiler' objects>\n"
+            r"( +1 +0 +0\.\d+ +0\.\d+ +<method 'disable' of '_lsprof\.Profiler' objects>\n)?"
             )
 
 

=== modified file 'bzrlib/tree.py'
--- bzrlib/tree.py	2006-06-03 16:23:09 +0000
+++ bzrlib/tree.py	2006-06-06 05:29:39 +0000
@@ -167,6 +167,11 @@
             return ie.text_sha1
         return None
 
+    def get_file_mtime(self, file_id, path=None):
+        ie = self._inventory[file_id]
+        revision = self._branch.get_revision(ie.revision)
+        return revision.timestamp
+
     def is_executable(self, file_id, path=None):
         ie = self._inventory[file_id]
         if ie.kind != "file":

=== modified file 'bzrlib/workingtree.py'
--- bzrlib/workingtree.py	2006-05-27 09:24:05 +0000
+++ bzrlib/workingtree.py	2006-06-01 08:12:48 +0000
@@ -535,6 +535,11 @@
             path = self._inventory.id2path(file_id)
         return self._hashcache.get_sha1(path)
 
+    def get_file_mtime(self, file_id, path=None):
+        if not path:
+            path = self._inventory.id2path(file_id)
+        return os.lstat(self.abspath(path)).st_mtime
+
     if not supports_executable():
         def is_executable(self, file_id, path=None):
             return self._inventory[file_id].executable

=== modified file 'setup.py'
--- setup.py	2006-05-30 15:18:12 +0000
+++ setup.py	2006-06-04 10:55:31 +0000
@@ -81,10 +81,10 @@
 ########################
 
 setup(name='bzr',
-      version='0.8pre',
-      author='Martin Pool',
-      author_email='mbp@sourcefrog.net',
-      url='http://www.bazaar-ng.org/',
+      version='0.9pre',
+      author='Canonical Ltd',
+      author_email='bazaar-ng@lists.ubuntu.com',
+      url='http://bazaar-vcs.org/',
       description='Friendly distributed version control system',
       license='GNU GPL v2',
       packages=['bzrlib',

